import type { Feature, Point } from 'geojson';
import type Supercluster from './types';
import type { BBox, LatLng, Region } from './types';
export declare const regionToBBox: (region: Region) => BBox;
export declare const getMarkersRegion: (points: LatLng[]) => Region;
export declare const getMarkersCoordinates: (markers: Feature<Point>) => {
    longitude: number;
    latitude: number;
};
/**
 * Determines if a point is a cluster for `.properties` typesafe accessiblity
 * @param point ClusterFeature or PointFeature
 */
export declare const isPointCluster: <P, C>(point: Supercluster.ClusterFeature<C> | Supercluster.PointFeature<P>) => point is Supercluster.ClusterFeature<C>;
declare type CoordOptions = [number, number] | {
    latitude: number;
    longitude: number;
} | {
    lat: number;
    lng: number;
};
/**
 * Utility function to convert coordinates to a GeoJSON feature
 * @param coords The coordinates to be converted to a GeoJSON feature - can be an array of two coordinates, `{ lat: number; lng: number }`, or `{ latitude: number; longitude: number }`
 * @param props Additional optional properties to be added to the feature
 */
export declare const coordsToGeoJSONFeature: <T>(coords: CoordOptions, props?: T | undefined) => Supercluster.PointFeature<T | undefined>;
export {};
